@@ -5,13 +5,13 @@ use std::time::Duration;
 use cogo::go;
 
 fn main() {
-    let mut t = Arc::new(Ticker::new(Duration::from_secs(1)));
+    let mut t = Ticker::new_arc(Duration::from_secs(1));
     let tclone = t.clone();
     go!(move ||{
                 for x in tclone.as_ref() {
                    println!("tick {}", x);
                 }
-       });
+    });
     sleep(Duration::from_secs(3));
     t.stop();
 }
\ No newline at end of file
